@@ -3,4 +3,4 @@ localStorage.removeItem('timeOfActivity')
 localStorage.removeItem('seammLogin')
 
 localStorage.setItem('seammLogout', 'logout' + Math.random());
-window.location.href = '/'
\ No newline at end of file
+window.location.assign(window.location.origin)
\ No newline at end of file
